@@ -17,7 +17,7 @@ class ClaudeHTTPClientError(HTTPClientError):
 class ClaudeHTTPClient(HTTPClient, ClaudeHTTPClientProtocol):
     @handle_http_error(client="ClaudeHTTPClient", exception=ClaudeHTTPClientError)
     async def chat_api(self, request: ClaudeChatRequestSchema) -> Response:
-        return await self.post("/v1/messages", json=request.model_dump())
+        return await self.post("/v1/messages", json=request.model_dump(exclude_none=True))
 
     async def chat(self, request: ClaudeChatRequestSchema) -> ClaudeChatResponseSchema:
         response = await self.chat_api(request)
@@ -27,9 +27,13 @@ class ClaudeHTTPClient(HTTPClient, ClaudeHTTPClientProtocol):
 def get_claude_http_client() -> ClaudeHTTPClient:
     logger = get_logger("CLAUDE_HTTP_CLIENT")
     logger_event_hook = LoggerEventHook(logger=logger)
-    retry_transport = RetryTransport(logger=logger, transport=AsyncHTTPTransport())
+    retry_transport = RetryTransport(
+        logger=logger,
+        transport=AsyncHTTPTransport(verify=settings.vcs.http_client.verify)
+    )
 
     client = AsyncClient(
+        verify=settings.llm.http_client.verify,
         timeout=settings.llm.http_client.timeout,
         headers={
             "x-api-key": settings.llm.http_client.api_token_value,
