@@ -19,7 +19,8 @@ class GeminiHTTPClient(HTTPClient, GeminiHTTPClientProtocol):
     async def chat_api(self, request: GeminiChatRequestSchema) -> Response:
         meta = settings.llm.meta
         return await self.post(
-            f"/v1beta/models/{meta.model}:generateContent", json=request.model_dump()
+            f"/v1beta/models/{meta.model}:generateContent",
+            json=request.model_dump(exclude_none=True)
         )
 
     async def chat(self, request: GeminiChatRequestSchema) -> GeminiChatResponseSchema:
@@ -30,9 +31,13 @@ class GeminiHTTPClient(HTTPClient, GeminiHTTPClientProtocol):
 def get_gemini_http_client() -> GeminiHTTPClient:
     logger = get_logger("GEMINI_HTTP_CLIENT")
     logger_event_hook = LoggerEventHook(logger=logger)
-    retry_transport = RetryTransport(logger=logger, transport=AsyncHTTPTransport())
+    retry_transport = RetryTransport(
+        logger=logger,
+        transport=AsyncHTTPTransport(verify=settings.vcs.http_client.verify)
+    )
 
     client = AsyncClient(
+        verify=settings.llm.http_client.verify,
         timeout=settings.llm.http_client.timeout,
         headers={"x-goog-api-key": settings.llm.http_client.api_token_value},
         base_url=settings.llm.http_client.api_url_value,
