@@ -15,10 +15,14 @@ class GitLabHTTPClient:
 def get_gitlab_http_client() -> GitLabHTTPClient:
     logger = get_logger("GITLAB_HTTP_CLIENT")
     logger_event_hook = LoggerEventHook(logger=logger)
-    retry_transport = RetryTransport(logger=logger, transport=AsyncHTTPTransport())
+    retry_transport = RetryTransport(
+        logger=logger,
+        transport=AsyncHTTPTransport(verify=settings.vcs.http_client.verify)
+    )
 
     client = AsyncClient(
-        timeout=settings.llm.http_client.timeout,
+        verify=settings.vcs.http_client.verify,
+        timeout=settings.vcs.http_client.timeout,
         headers={"Authorization": f"Bearer {settings.vcs.http_client.api_token_value}"},
         base_url=settings.vcs.http_client.api_url_value,
         transport=retry_transport,
