@@ -21,8 +21,8 @@ class OpenRouterChoiceSchema(BaseModel):
 class OpenRouterChatRequestSchema(BaseModel):
     model: str
     messages: list[OpenRouterMessageSchema]
-    max_tokens: int
-    temperature: float
+    max_tokens: int | None = None
+    temperature: float | None = None
 
 
 class OpenRouterChatResponseSchema(BaseModel):
