@@ -19,8 +19,11 @@ class ReviewMode(StrEnum):
 
 class ReviewConfig(BaseModel):
     mode: ReviewMode = ReviewMode.FULL_FILE_DIFF
+    dry_run: bool = False
     inline_tag: str = Field(default="#ai-review-inline")
+    inline_reply_tag: str = Field(default="#ai-review-inline-reply")
     summary_tag: str = Field(default="#ai-review-summary")
+    summary_reply_tag: str = Field(default="#ai-review-summary-reply")
     context_lines: int = Field(default=10, ge=0)
     allow_changes: list[str] = Field(default_factory=list)
     ignore_changes: list[str] = Field(default_factory=list)
