@@ -5,4 +5,6 @@ class VCSProvider(StrEnum):
     GITEA = "GITEA"
     GITHUB = "GITHUB"
     GITLAB = "GITLAB"
-    BITBUCKET = "BITBUCKET"
+    AZURE_DEVOPS = "AZURE_DEVOPS"
+    BITBUCKET_CLOUD = "BITBUCKET_CLOUD"
+    BITBUCKET_SERVER = "BITBUCKET_SERVER"
